<?xml version="1.0" encoding="UTF-8"?>
<!-- Addenda para CFD Aluprint MIRO, MRKO y FB60 
  :: By Daniel Herrera T. -->
 <!-- Ultima modificacion DHT 27/07/2012. Se agrego una condicion para filtrar el xsl:for-each para reportar solo los pedidos que tienen referencia a una Recepcion-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="html" encoding="UTF-8"/>
	<xsl:template match="/">
		<xsl:element name="requestForPayment">
			<xsl:attribute name="documentStructureVersion">1.0</xsl:attribute>
			<xsl:attribute name="deliveryDate"><xsl:value-of select="concat(substring(Datos/CFD/@Fecha,1,4),substring(Datos/CFD/@Fecha,6,2),substring(Datos/CFD/@Fecha,9,2))"/></xsl:attribute>
			<xsl:element name="entityType">
				<xsl:variable name="tpodoc" select="Datos/Documento/@TipoDocumento"/>
				<xsl:choose>
					<xsl:when test="$tpodoc = 0">
							<xsl:text>Factura</xsl:text>
					</xsl:when>
					<xsl:when test="$tpodoc = 1">
							<xsl:text>Factura</xsl:text>
					</xsl:when>
					<xsl:when test="$tpodoc = 2">
						<xsl:text>Nota_Credito</xsl:text>
					</xsl:when>
					<xsl:when test="$tpodoc = 3">
						<xsl:text>Nota_Debito</xsl:text>
					</xsl:when>
					<xsl:when test="$tpodoc = 4">
						<xsl:text>Honorarios</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>NO_DEFINIDO</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:element>
		</xsl:element>
		<xsl:element name="specialInstruction">
			<xsl:element name="code">
				<xsl:value-of select="Datos/Documento/XMLAddenda/Documento/Generales/@Code"/>
			</xsl:element>
			<xsl:element name="referenceNumber">
				<xsl:value-of select="Datos/Documento/XMLAddenda/Documento/Generales/@NotaEntrega"/>
			</xsl:element>
		</xsl:element>
		<xsl:variable name="recepciones" select="count(/Datos/Documento/XMLAddenda/Documento/Pedidos/Pedido/Recepcion [@NumeroRecepcion != ''])"/>
		<xsl:if test="$recepciones &gt; 0">
			<xsl:element name="orderIdentification">
				<xsl:for-each select="Datos/Documento/XMLAddenda/Documento/Pedidos/Pedido[Recepcion/@NumeroRecepcion != '']">
					<xsl:variable name="numrecep" select="count(Recepcion [@NumeroRecepcion != ''])"/>
					<xsl:if test="$numrecep &gt; 0">
						<xsl:element name="secuence">
							<xsl:attribute name="consec">
								<xsl:value-of select="position()"/>
							</xsl:attribute>
							<xsl:if test="@NumeroPedido !=''">
								<xsl:element name="referenceIdentification">
									<xsl:value-of select="@NumeroPedido"/>
								</xsl:element>
							</xsl:if>
							<xsl:element name="deliveryNote">
								<xsl:for-each select="Recepcion">
									<xsl:if test="@NumeroRecepcion != ''">
										<xsl:element name="deliveryIdentification">
											<xsl:value-of select="@NumeroRecepcion"/>
										</xsl:element>
									</xsl:if>
								</xsl:for-each>
							</xsl:element>
						</xsl:element>
					</xsl:if>
				</xsl:for-each>
			</xsl:element>
		</xsl:if>
		<xsl:if test="Datos/Documento/XMLAddenda/Documento/Generales/@NoPedimento !=''">
			<xsl:element name="customs">
				<xsl:element name="alternatePartyIdentification">
					<xsl:value-of select="Datos/Documento/XMLAddenda/Documento/Generales/@NoPedimento"/>
				</xsl:element>
			</xsl:element>
		</xsl:if>
		<xsl:element name="currency">
			<xsl:element name="currencyISOCode">
				<xsl:variable name="tpomon" select="Datos/Documento/@TipoMoneda"/>
				<xsl:choose>
					<xsl:when test="$tpomon = 0">
						<xsl:text>MXN</xsl:text>
					</xsl:when>
					<xsl:when test="$tpomon = 1">
						<xsl:text>MXN</xsl:text>
					</xsl:when>
					<xsl:when test="$tpomon = 2">
						<xsl:text>USD</xsl:text>
					</xsl:when>
					<xsl:when test="$tpomon = 3">
						<xsl:text>XEU</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:element>
			<xsl:element name="rateOfChange">
				<xsl:value-of select="format-number(Datos/Documento/@TipoCambio,'0.00')"/>
			</xsl:element>
		</xsl:element>
		<xsl:if test="/Datos/Documento/XMLAddenda/Documento/Generales/@baseISR &gt; 0 or /Datos/Documento/XMLAddenda/Documento/Generales/@baseIVA &gt; 0">
			<xsl:element name="baseTaxes">
				<xsl:if test="/Datos/Documento/XMLAddenda/Documento/Generales/@baseISR &gt; 0">
					<xsl:element name="baseISR">
						<xsl:value-of select="format-number(/Datos/Documento/XMLAddenda/Documento/Generales/@baseISR,'0.00')"/>
					</xsl:element>
				</xsl:if>
				<xsl:if test="/Datos/Documento/XMLAddenda/Documento/Generales/@baseIVA &gt; 0">
					<xsl:element name="baseRet">
						<xsl:value-of select="format-number(/Datos/Documento/XMLAddenda/Documento/Generales/@baseIVA,'0.00')"/>
					</xsl:element>
				</xsl:if>
			</xsl:element>
		</xsl:if>
		<xsl:variable name="especiales" select="count(/Datos/Documento/XMLAddenda/Documento/ServiciosEspeciales/ServicioEspecial [@TipoDescuentoCargo != ''])"/>
		<xsl:if test="$especiales &gt; 0">
			<xsl:element name="specialServices">
				<xsl:for-each select="/Datos/Documento/XMLAddenda/Documento/ServiciosEspeciales/ServicioEspecial">
					<xsl:if test="@TipoDescuentoCargo !=''">
						<xsl:element name="sequenceNumber">
							<xsl:element name="specialServicesType">
								<xsl:value-of select="@TipoDescuentoCargo"/>
							</xsl:element>
							<xsl:element name="monetaryAmountOrPercentage">
								<xsl:value-of select="format-number(@Cantidad,'0.00')"/>
							</xsl:element>
						</xsl:element>
					</xsl:if>
				</xsl:for-each>
			</xsl:element>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>